==> azure_translate-0.1.tar.gz: azure_translate-0.1/setup.py <==
from setuptools import setup

long_description = open("azure_translate/README.md").read()
setup(
    name='azure_translate',  # How you named your package folder (MyLib)
    packages=['azure_translate'],  # Chose the same as "name"
    package_data={
        'azure_translate': ['*.hy', '*.md', '*.py']
    },
    version='0.1',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='Azure translate engine',  # Give a short description about your library
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='ShinSheel',  # Type in your name
    author_email='wladgavrilov@gmail.com',  # Type in your E-Mail
    url='https://github.com/user/reponame',  # Provide either the link to your github or to your website
    download_url='https://github.com/user/reponame/archive/v_01.tar.gz',  # I explain this later on
    keywords=['Qwant', 'search', 'engine'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'requests'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',  # Again, pick a license

        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)

==> azure_translate-0.1.1.tar.gz: azure_translate-0.1.1/setup.py <==
from setuptools import setup

long_description = open("azure_translate/README.md").read()
setup(
    name='azure_translate',  # How you named your package folder (MyLib)
    packages=['azure_translate'],  # Chose the same as "name"
    package_data={
        'azure_translate': ['*.hy', '*.md', '*.py']
    },
    version='0.1.1',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='Azure translate engine',  # Give a short description about your library
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='ShinSheel',  # Type in your name
    author_email='wladgavrilov@gmail.com',  # Type in your E-Mail
    url='https://github.com/user/reponame',  # Provide either the link to your github or to your website
    download_url='https://github.com/user/reponame/archive/v_01.tar.gz',  # I explain this later on
    keywords=['Azure', 'translator', 'engine'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'requests'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',  # Again, pick a license

        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
